@@ -1,24 +1,23 @@
-# @(#)$Id: Cache.pm 238 2011-01-26 18:13:06Z pjf $
+# @(#)$Id: Cache.pm 253 2011-04-02 01:10:20Z pjf $
 
 package File::DataClass::Cache;
 
 use strict;
 use namespace::autoclean;
-use version; our $VERSION = qv( sprintf '0.3.%d', q$Rev: 238 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.3.%d', q$Rev: 253 $ =~ /\d+/gmx );
 
 use CHI;
-use Class::Null;
 use File::DataClass::Constants;
 use Moose;
 
-with qw(File::DataClass::Util);
+with qw(File::DataClass::Constraints File::DataClass::Util);
 
+has 'cache'            => is => 'ro', isa => 'Object',
+   lazy_build          => TRUE;
 has 'cache_attributes' => is => 'ro', isa => 'HashRef',
    default             => sub { return {} };
 has 'cache_class'      => is => 'ro', isa => 'ClassName',
    default             => q(CHI);
-has 'cache'            => is => 'ro', isa => 'Object',
-   lazy_build          => TRUE;
 has 'schema'           => is => 'ro', isa => 'Object',
    required            => 1, weak_ref => TRUE,
    handles             => { _debug => q(debug), _log => q(log), };
@@ -93,8 +92,6 @@ sub _build_cache {
 
    my $class = delete $attrs->{cache_class} || $self->cache_class;
 
-   $class eq q(none) and return Class::Null->new;
-
    $attrs->{on_set_error} = sub { $self->_log->error( $_[ 0 ] ) };
 
    return $class->new( %{ $attrs } );
@@ -127,7 +124,7 @@ File::DataClass::Cache - Adds extra methods to the CHI API
 
 =head1 Version
 
-0.3.$Revision: 238 $
+0.3.$Revision: 253 $
 
 =head1 Synopsis
 
