@@ -1,10 +1,10 @@
-# @(#)$Id: XML.pm 238 2011-01-26 18:13:06Z pjf $
+# @(#)$Id: XML.pm 254 2011-04-03 01:11:13Z pjf $
 
 package File::DataClass::Storage::XML;
 
 use strict;
 use namespace::autoclean;
-use version; our $VERSION = qv( sprintf '0.3.%d', q$Rev: 238 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.3.%d', q$Rev: 254 $ =~ /\d+/gmx );
 
 use File::DataClass::Constants;
 use XML::DTD;
@@ -13,9 +13,11 @@ use Moose;
 extends qw(File::DataClass::Storage);
 
 has '+extn'     => default => q(.xml);
-has 'root_name' => is => 'ro', isa => 'Str',      default => q(config);
-has '_arrays'   => is => 'rw', isa => 'HashRef',  default => sub { return {} };
-has '_dtd'      => is => 'rw', isa => 'ArrayRef', default => sub { return [] };
+has 'root_name' => is => 'ro', isa => 'Str',      default  => q(config);
+has '_arrays'   => is => 'rw', isa => 'F_DC_HashRefOfBools',
+   coerce       => TRUE,  init_arg => 'force_array',
+   default      => sub { return {} };
+has '_dtd'      => is => 'rw', isa => 'ArrayRef', default  => sub { return [] };
 
 around '_meta_pack' => sub {
    my ($orig, $self, $args) = @_; my $packed = $self->$orig( $args );
@@ -109,7 +111,7 @@ File::DataClass::Storage::XML - Read/write XML data storage model
 
 =head1 Version
 
-0.3.$Revision: 238 $
+0.3.$Revision: 254 $
 
 =head1 Synopsis
 
